@@ -16,7 +16,7 @@ Including another URLconf
 # from django.contrib import admin
 from django.urls import path
 
-from apps.bi_report.views import BaseAPIView
+from report_diff.bi_report.views import BaseAPIView
 
 urlpatterns = [
        path('test/', BaseAPIView.as_view()),
