@@ -17,5 +17,5 @@ Including another URLconf
 from django.urls import path, include
 
 urlpatterns = [
-       path('', include('apps.bi_report.urls')),
+       path('bi/', include('report_diff.bi_report.urls'))
 ]
